aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael Everitt <m.j.everitt@iee.org>2018-09-09 18:17:27 +0100
committerBrian Dolbec dolsen <dolsen@gentoo.org>2018-10-01 09:19:50 -0700
commit53c9407e9aae76b4d2284f7eba3e650895923555 (patch)
treea8bad861d5ce1cdd6bac229b43e2e750767294cb
parentAdd .git folder to snapshot rsync excludes (diff)
downloadcatalyst-53c9407e9aae76b4d2284f7eba3e650895923555.tar.gz
catalyst-53c9407e9aae76b4d2284f7eba3e650895923555.tar.bz2
catalyst-53c9407e9aae76b4d2284f7eba3e650895923555.zip
Fix mis-spelling of 'received' in chroot-functions.sh
-rwxr-xr-xtargets/support/chroot-functions.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/targets/support/chroot-functions.sh b/targets/support/chroot-functions.sh
index 84d90fe9..ceef21ca 100755
--- a/targets/support/chroot-functions.sh
+++ b/targets/support/chroot-functions.sh
@@ -3,19 +3,19 @@
# Set the profile
eselect profile set ${clst_target_profile}
# Trap these signals and kill ourselves if recieved
# Force ourselves to die if any of these signals are recieved
# most likely our controlling terminal is gone
-trap "echo SIGTERM signal recieved killing $0 with pid $$;kill -9 $$" SIGTERM
-trap "echo SIGHUP signal recieved killing $0 with pid $$;kill -9 $$" SIGHUP
-trap "echo SIGKILL signal recieved killing $0 with pid $$;kill -9 $$" SIGKILL
+trap "echo SIGTERM signal received killing $0 with pid $$;kill -9 $$" SIGTERM
+trap "echo SIGHUP signal received killing $0 with pid $$;kill -9 $$" SIGHUP
+trap "echo SIGKILL signal received killing $0 with pid $$;kill -9 $$" SIGKILL
#SIGINT interrupt character (usually Ctrl-C)
# * example: high-level sequence of events
# * my process (call it "P") is running
# * user types ctrl-c
# * kernel recognizes this and generates SIGINT signal
-trap "echo SIGINT signal recieved killing $0 with pid $$;kill -9 $$" SIGINT
+trap "echo SIGINT signal received killing $0 with pid $$;kill -9 $$" SIGINT
# test if CHOST was set on the python side
if [[ -z "${clst_CHOST}" ]] ; then
@@ -3,19 +3,19 @@
# Set the profile
eselect profile set ${clst_target_profile}
-# Trap these signals and kill ourselves if recieved
-# Force ourselves to die if any of these signals are recieved
+# Trap these signals and kill ourselves if received
+# Force ourselves to die if any of these signals are received
# most likely our controlling terminal is gone